package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERString;
import cn.com.infosec.asn1.DERTaggedObject;

public class RoleSyntax extends ASN1Encodable {
   private GeneralNames roleAuthority;
   private GeneralName roleName;

   public static RoleSyntax getInstance(Object obj) {
      if (obj != null && !(obj instanceof RoleSyntax)) {
         if (obj instanceof ASN1Sequence) {
            return new RoleSyntax((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Unknown object in RoleSyntax factory.");
         }
      } else {
         return (RoleSyntax)obj;
      }
   }

   public RoleSyntax(GeneralNames roleAuthority, GeneralName roleName) {
      if (roleName != null && roleName.getTagNo() == 6 && !((DERString)roleName.getName()).getString().equals("")) {
         this.roleAuthority = roleAuthority;
         this.roleName = roleName;
      } else {
         throw new IllegalArgumentException("the role name MUST be non empty and MUST use the URI option of GeneralName");
      }
   }

   public RoleSyntax(GeneralName roleName) {
      this((GeneralNames)null, roleName);
   }

   public RoleSyntax(String roleName) {
      GeneralName var2 = new GeneralName;
      byte var3 = 6;
      if (roleName == null) {
         roleName = "";
      }

      var2.<init>(var3, (String)roleName);
      this(var2);
   }

   public RoleSyntax(ASN1Sequence seq) {
      if (seq.size() >= 1 && seq.size() <= 2) {
         for(int var2 = 0; var2 != seq.size(); ++var2) {
            ASN1TaggedObject var3;
            int var4;
            if ((var4 = (var3 = ASN1TaggedObject.getInstance(seq.getObjectAt(var2))).getTagNo()) != 0) {
               if (var4 != 1) {
                  throw new IllegalArgumentException("Unknown tag in RoleSyntax");
               }

               this.roleName = GeneralName.getInstance(var3, false);
            } else {
               this.roleAuthority = GeneralNames.getInstance(var3, false);
            }
         }

      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public GeneralNames getRoleAuthority() {
      return this.roleAuthority;
   }

   public GeneralName getRoleName() {
      return this.roleName;
   }

   public String getRoleNameAsString() {
      return ((DERString)this.roleName.getName()).getString();
   }

   public String[] getRoleAuthorityAsString() {
      GeneralNames var4;
      if ((var4 = this.roleAuthority) == null) {
         return new String[0];
      } else {
         GeneralName[] var5;
         String[] var1 = new String[(var5 = var4.getNames()).length];

         for(int var2 = 0; var2 < var5.length; ++var2) {
            DEREncodable var3;
            if ((var3 = var5[var2].getName()) instanceof DERString) {
               var1[var2] = ((DERString)var3).getString();
            } else {
               var1[var2] = var3.toString();
            }
         }

         return var1;
      }
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      GeneralNames var2;
      if ((var2 = this.roleAuthority) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(false, 0, var2);
         var1.add(var3);
      }

      DERTaggedObject var5;
      DERTaggedObject var10001 = var5 = new DERTaggedObject;
      GeneralName var4 = this.roleName;
      var10001.<init>(false, 1, var4);
      var1.add(var5);
      return new DERSequence(var1);
   }

   public String toString() {
      StringBuffer var1;
      var1 = new StringBuffer.<init>("Name: " + this.getRoleNameAsString() + " - Auth: ");
      GeneralNames var2;
      if ((var2 = this.roleAuthority) != null && var2.getNames().length != 0) {
         String[] var3 = this.getRoleAuthorityAsString();
         var1.append('[').append(var3[0]);

         for(int var4 = 1; var4 < var3.length; ++var4) {
            var1.append(", ").append(var3[var4]);
         }

         var1.append(']');
      } else {
         var1.append("N/A");
      }

      return var1.toString();
   }
}
